=====
aDMIX
=====


.. image:: https://img.shields.io/pypi/v/xe-admix.svg
        :target: https://pypi.python.org/pypi/xe-admix

.. image:: https://travis-ci.com/XENONnT/admix.svg?branch=master
        :target: (https://travis-ci.com/XENONnT/admix

.. image:: https://readthedocs.org/projects/admix/badge/?version=latest
        :target: https://advance-data-management-in-xenon.readthedocs.io/en/latest/
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/XeBoris/admix/shield.svg
     :target: https://pyup.io/repos/github/XeBoris/admix/
     :alt: Updates


Python Boilerplate contains all the boilerplate you need to create a Python package.


* Free software: BSD license
* Documentation: https://advance-data-management-in-xenon.readthedocs.io/en/latest/


Features
--------

* Improve in Rucio uploads on a multi-scale level

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

